pub struct TriangleHit {
pub ground: Option<Ground>,
pub push: Vector<f32>,
}Expand description
The result of resolving a capsule against a single mesh.
Fields
ground: Option<Ground>The walkable ground of this mesh supporting the capsule, if any.
push: Vector<f32>The accumulated displacement out of steep geometry.