pub struct TriangleHit {
pub grounded: bool,
pub ground_y: f32,
pub ground_normal: Vector<f32>,
pub push: Vector<f32>,
}Expand description
The result of resolving a capsule against a single mesh.
Fields
grounded: boolWhether the capsule is supported by walkable ground of this mesh.
ground_y: f32The height of the supporting ground.
ground_normal: Vector<f32>The face normal of the supporting ground.
push: Vector<f32>The accumulated displacement out of steep geometry.